@@ -1,4 +1,4 @@
-# $Id: mvnorm.R 275 2014-05-02 22:07:27Z mmaechler $
+# $Id: mvnorm.R 332 2016-10-27 09:17:12Z thothorn $
 
 rmvnorm <- function(n, mean = rep(0, nrow(sigma)), sigma = diag(length(mean)),
                    method=c("eigen", "svd", "chol"), pre0.9_9994 = FALSE)
@@ -15,18 +15,18 @@ rmvnorm <- function(n, mean = rep(0, nrow(sigma)), sigma = diag(length(mean)),
     R <- if(method == "eigen") {
         ev <- eigen(sigma, symmetric = TRUE)
         if (!all(ev$values >= -sqrt(.Machine$double.eps) * abs(ev$values[1]))){
-            warning("sigma is numerically not positive definite")
+            warning("sigma is numerically not positive semidefinite")
         }
         ## ev$vectors %*% diag(sqrt(ev$values), length(ev$values)) %*% t(ev$vectors)
         ## faster for large  nrow(sigma):
-        t(ev$vectors %*% (t(ev$vectors) * sqrt(ev$values)))
+        t(ev$vectors %*% (t(ev$vectors) * sqrt(pmax(ev$values, 0))))
     }
     else if(method == "svd"){
         s. <- svd(sigma)
         if (!all(s.$d >= -sqrt(.Machine$double.eps) * abs(s.$d[1]))){
-            warning("sigma is numerically not positive definite")
+            warning("sigma is numerically not positive semidefinite")
         }
-        t(s.$v %*% (t(s.$u) * sqrt(s.$d)))
+        t(s.$v %*% (t(s.$u) * sqrt(pmax(s.$d, 0))))
     }
     else if(method == "chol"){
         R <- chol(sigma, pivot = TRUE)
